#
# spec file for package usbguard
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global _hardened_build 1
%define lname libusbguard1
Name:           usbguard
Version:        1.1.3
Release:        1.6
Summary:        A tool for implementing USB device usage policy
## Not installed
# src/ThirdParty/Catch: Boost Software License - Version 1.0
License:        GPL-2.0-or-later
Group:          System/Daemons
URL:            https://usbguard.github.io
Source0:        https://github.com/USBGuard/usbguard/releases/download/usbguard-%{version}/usbguard-%{version}.tar.gz
Source1:        https://github.com/USBGuard/usbguard/releases/download/usbguard-%{version}/usbguard-%{version}.tar.gz.sum.asc
Source2:        usbguard.keyring
Source3:        usbguard-daemon.conf
Source4:        usbguard-rpmlintrc
Patch0:         usbguard-pthread.patch
BuildRequires:  asciidoc
BuildRequires:  audit-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bash-completion-devel
BuildRequires:  dbus-1-glib-devel
%if 0%{?suse_version} == 1500
BuildRequires:  gcc10-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  libcap-ng-devel
BuildRequires:  libqb-devel
BuildRequires:  libseccomp-devel
BuildRequires:  libsodium-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  polkit-devel
#BuildRequires:  spdlog-static
BuildRequires:  protobuf-devel
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udev)
%{?systemd_requires}

%description
The USBGuard software framework helps to protect your computer against rogue USB
devices by implementing basic whitelisting/blacklisting capabilities based on
USB device attributes.

%package -n %{lname}
Summary:        Library for implementing USB device usage policy
Group:          System/Libraries
Obsoletes:      libusbguard0 < %{version}

%description -n %{lname}
The USBGuard software framework helps to protect your computer against rogue USB
devices by implementing basic whitelisting/blacklisting capabilities based on
USB device attributes.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}
Requires:       %{name} = %{version}
Requires:       libstdc++-devel
Requires:       pkgconfig

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package        tools
Summary:        USBGuard Tools
Group:          System/Management
Requires:       %{name} = %{version}-%{release}

%description    tools
The %{name}-tools package contains optional tools from the USBGuard
software framework.

%prep
%autosetup -p1 -n usbguard-%{version}

%build
%if 0%{?suse_version} == 1500
export CXX=g++-10
# gcc10 has no gcc10-PIE yet, enforce manually (see boo#1195628 for progress)
export CPPFLAGS='-fPIE'
export LDFLAGS='-pie'
%endif
mkdir -p ./m4
autoreconf -fiv

%configure \
    --disable-silent-rules \
    --with-bundled-catch \
    --with-bundled-pegtl \
    --enable-systemd \
    --with-dbus \
    --disable-static

make %{?_smp_mflags}

%check
# while we specify --with-bundled-catch, it is not there :(
# make check

%install
%make_install INSTALL="install -p"
ln -sf %{_sbindir}/service %{buildroot}/%{_sbindir}/rcusbguard

# Install configuration
mkdir -p %{buildroot}%{_sysconfdir}/usbguard
install -p -m 600 %{SOURCE3} %{buildroot}%{_sysconfdir}/usbguard/usbguard-daemon.conf

# zsh completion, currently needs manual intervention
mkdir -p %{buildroot}%{_datadir}/zsh/site-functions/
install -p -m 644 scripts/usbguard-zsh-completion %{buildroot}%{_datadir}/zsh/site-functions/_usbguard

# turn off system call filtering in Leap 15.X, as it interferes with daemon start up (boo#1173750)
%if 0%{?suse_version} == 1500 && 0%{?is_opensuse}
  sed -i '/^SystemCallFilter=@system-service/d' %{buildroot}%{_unitdir}/usbguard.service
%endif

# Cleanup
find %{buildroot} \( -name '*.la' -o -name '*.a' \) -delete

%preun
%service_del_preun usbguard.service usbguard-dbus.service

%post
%service_add_post usbguard.service usbguard-dbus.service

%postun
%service_del_postun usbguard.service usbguard-dbus.service

%pre
%service_add_pre usbguard.service usbguard-dbus.service

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files
%doc README.adoc CHANGELOG.md
%license LICENSE
%{_sbindir}/usbguard-daemon
%dir %{_localstatedir}/log/usbguard
%dir %{_sysconfdir}/usbguard
%{_sbindir}/rcusbguard
%{_sbindir}/usbguard-dbus
%dir %{_sysconfdir}/usbguard/IPCAccessControl.d
%config(noreplace) %attr(0600,-,-) %{_sysconfdir}/usbguard/usbguard-daemon.conf
%config(noreplace) %attr(0600,-,-) %{_sysconfdir}/usbguard/rules.conf
%{_unitdir}/usbguard.service
%{_unitdir}/usbguard-dbus.service
%{_mandir}/man8/usbguard-daemon.8%{?ext_man}
%{_mandir}/man8/usbguard-dbus.8%{?ext_man}
%{_mandir}/man5/usbguard-daemon.conf.5%{?ext_man}
%{_mandir}/man5/usbguard-rules.conf.5%{?ext_man}
%{_datadir}/bash-completion/completions/usbguard
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_usbguard
%{_datadir}/dbus-1/system-services/org.usbguard1.service
%{_datadir}/dbus-1/system.d/org.usbguard1.conf
%{_datadir}/polkit-1/actions/org.usbguard1.policy

%files -n %{lname}
%license LICENSE
%{_libdir}/*.so.*

%files devel
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files tools
%{_bindir}/usbguard
%{_bindir}/usbguard-rule-parser
%{_mandir}/man1/usbguard.1%{?ext_man}

%changelog
* Thu Jun  6 2024 Robert Frohl <rfrohl@suse.com>
- update to 1.1.3
  * Fix typo in CLI --help message: "privilges" -> "privileges"
  * Harden service file: Set OOMScoreAdjust to -1000
  * Specify what happens when neither RuleFile nor RuleFolder is set
  * The parent process should wait for the first child process to finish in forking mode(-f)
  * dbus: check whether the client wanted interactive authentication
  * Add missing .adoc files to the tarball
  * Replace problematic terms with alternatives
  * Fix CI by fixing calls to ldap-utils
  * Describe comments in the manual page
  * Store permanent rules even if RuleFile is not set but RuleFolder is.
  * Fix build for GCC 13 + make GitHub Actions cover build with GCC 13
  * Bump GitHub Actions off deprecated actions/checkout@v2
  * Actions(deps): Bump actions/checkout from 3.5.2 to 4.1.1
  * Add "--version" option to the usbguard CLI
  * ruleset: detect integer overflow of the ID and bail out
  * Enable RuleFolder by default
  * Fix CI and RuleSet::assignID regressions
- Removed build_gcc13.patch, included upstream
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Tue Mar 28 2023 Robert Frohl <rfrohl@suse.com>
- Fix build failure with gcc13, add build_gcc13.patch.
* Mon Sep  5 2022 Robert Frohl <rfrohl@suse.com>
- update to 1.1.2
  * Fixed
  - Polkit: Always allow getParameter/listDevices/listRules in active sessions
  - D-Bus: Send reply on auth failure
  - Polkit: Unreference PolkitAuthorizationResult and PolkitAuthority structs if needed
* Tue Apr  5 2022 Dominique Leuenberger <dimstar@opensuse.org>
- When running autoreconf, do it complete so that it does not trip
  over different versions of libtool being used.
* Wed Mar 16 2022 Robert Frohl <rfrohl@suse.com>
- update to 1.1.1
  * Fixed/Changed
  - Use authentication instead of authentification
  - Restore support for access control filenames without a group
* Tue Mar  1 2022 Robert Frohl <rfrohl@suse.com>
- Enable dbus support (bsc#1196621, jsc#PED-3824).
* Fri Feb 25 2022 Robert Frohl <rfrohl@suse.com>
- Fix build for Leap and SLE by using newer gcc version
* Thu Feb 24 2022 Robert Frohl <rfrohl@suse.com>
- update to 1.1.0
  * Added
  - Started building with C++17
  - Tree-like list-devices output
  - Added CAP_AUDIT_WRITE capability to service file
  - Added support for lower OpenSSL versions prior to 1.1.0
  - Added a new signal: DevicePolicyApplied
  * Fixed/Changed
  - Moved PIDFile from /var/run to /run
  - Fixed linker isssues with disable-static
  - Enhanced bash-completion script
  - Make username/group checking consistent with useradd manual page definition (with addition of capital letters)
  - Fixed multiple IPC related bugs
  - Fixed race condition when accessing port/connect_type for USB devices
  - Using bundled catch v2.13.8
  - Using bundled PEGTL v3.2.5
  - Fixed usbguard-rule-parser file opening
  - CVE-2019-25058: Fix unauthorized access via D-Bus (boo#1196460)
- remove usbguard.service.in.patch applied upstream
* Thu Aug  5 2021 Robert Frohl <rfrohl@suse.com>
- move usbguard.pid from /var/run to /run
  added usbguard.service.in.patch
* Wed Jan 13 2021 Robert Frohl <rfrohl@suse.com>
- update to 1.0.0
  * Added openssl support
  * Starting with libtool versioning
  * Added interface for IPC permission query
  * Introduced partial rule concept fo CLI
  * Added WithConnectType for ldap rule
  * Daemon does not apply the policy when "change" action event appears anymore
  * IPCClientPrivate@disconnect is thread safe
  * Enforced loading of files from .d/ direcory in alfabetical order
  * Improved CLI behaviour to be consistent
  * Clarified rule's label documentation
* Fri Oct  2 2020 pgajdos@suse.com
- drop useless build dependency on aspell (aspell is going to be
  removed from tumbleweed)
* Thu Jul  9 2020 Robert Frohl <rfrohl@suse.com>
- disable system call filtering in systemd service file for Leap 15.X (boo#1173750)
  * daemon wont start on Leap otherwise
* Tue Jun 16 2020 Robert Frohl <rfrohl@suse.com>
- update to 0.7.8
  + Fixed segfaults with rules.d feature
- update to 0.7.7
  + Added readwritepath to service file
  + Added match-all keyword to rules language
  + Added rules.d feature: daemon can load multiple rule files from rules.d/
  + Included with-connect-type in dbus signal
  + Fixed sigwaitinfo handling
  + Fixed possible data corruption on stack with appendRule via dbus
  + Fixed ENOBUFS errno handling on netlink socket: daemon can survive and wait until socket is readable again
  + Dropped unused PIDFile from service file
  + Dropped deprecated dbus-glib dependency
* Thu Jan 30 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 0.7.6
  + Added missing options in manpage usbguard-daemon(8)
  + Extended the functionality of allow/block/reject commands
    The command can handle rule as a param and not only its ID e.g.
    in case of allow, command will allow each device that matches
    provided rule
  + Added debug info for malformed descriptors
  + Changed default backend to uevent
  + Fixed handling of add uevents during scanning
    Now we are sure that the enumeration is completed before
    processing any uevent we are trying to avoid a race where
    the kernel is still enumerating the devices and send the
    uevent while the parent is being authorised
  + Silenced 'bind' and 'unbind' uevents
- Remove PEGTL build dependency, the package already uses the
  bundled version, and there is hardly any reason to unbundle
  a template (header only) library.
- Remove Qt5 build dependencies, Qt applet is a separate package.
- Use pkgconfig(udev) instead of udev-devel to allow shortcut
  via udev-mini.
* Mon Jul 22 2019 Robert Frohl <rfrohl@suse.com>
- update to 0.7.5
  - Added daemon configuration option HidePII
  - Added check to avoid conflict between ASAN and TSAN
  - Added daemon configuration option for authorized_default
  - Added devpath option to generate-policy
  - Added # line comments to the rule grammar
  - Added ImplicitPolicyTarget to get/set parameter methods
  - Added option to filter rules by label when listing
  - Added the label attribute to rule
  - Added PropertyParameterChanged signal
  - Added support for portX/connect_type attribute
  - Added temporary option to append-rule
  - Added versioning to DBus service
  - Added optional LDAP support
  - Fixed invalid return value in Rule::Attribute::setSolveEqualsOrdered
  - Fixed KeyValueParser to validate keys only when known names are set
  - Fixed uninitialized variables found by coverity
  - Fixes and cleanups based on LGTM.com report
  - Hardened systemd service
  - Rename ListRules parameter 'query' to 'label'
  - Skip empty lines in usbguard-rule-parser
  - The proof-of-concept Qt applet was removed. It is going to be maintained
    in a simplified form as a separate project.
    Removed: usbguard-applet-qt_desktop_menu_categories.patch
    Modified: usbguard-pthread.patch
- Updated usbguard.keyring to add new gpg key for upstream: 5A2EC3932A983910
* Mon Jul 22 2019 Marcus Meissner <meissner@suse.com>
- link against libpthread to make it build (bsc#1141377)
- added usbguard-pthread.patch
* Wed May 22 2019 Christophe Giboudeaux <christophe@krop.fr>
- Run spec-cleaner
- Add the missing systemd build requirement.
* Tue Jan 15 2019 Robert Frohl <rfrohl@suse.com>
- use upstream usbguard.service instead of hardcoded version (bsc#1120969)
* Wed Nov  7 2018 Jan Engelhardt <jengelh@inai.de>
- Fix RPM groups. Avoid pointless shelling out to /bin/rm.
* Tue Oct  9 2018 Robert Frohl <rfrohl@suse.com>
- changed zsh completion location
- added rpmlint for zero size rules.conf
* Tue Oct  9 2018 Robert Frohl <rfrohl@suse.com>
- added signature verification of tarball
  - add usbguard-0.7.4.tar.gz.sig
  - add usbguard.keyring
* Mon Oct  8 2018 Robert Frohl <rfrohl@suse.com>
- update to 0.7.4
  - Changed
    Fixed conditional manual page generation & installation
- update to 0.7.3
  - Changed
    usbguard-daemon will now exit with an error if it fails to open a logging file or audit event file.
    Modified the present device enumeration algorithm to be more reliable.  Enumeration timeouts won't cause usbguard-daemon process to exit anymore.
  - Added
    umockdev based device manager capable of simulating devices based on umockdev-record files.
- update to 0.7.2
  - Changed
    Fixed memory leaks in usbguard::Hash class.
    Fixed file descriptor leaks in usbguard::SysFSDevice class.
    Skip audit backend logging when no backend was set.
  - Added
    Added zsh completion & other scripts to the distribution tarball.
- update to 0.7.1
  - Added
    CLI: usbguard watch command now includes an -e <path> option to run an executable for every received event. Event data are passed to the executable via environment variables.
    usbguard-daemon: added "-K" option which can disable logging to console.
    Added zsh autocompletion support.
    usbguard-daemon: added "-f" option which enabled double-fork daemonization procedure.
    Added AuditBackend usbguard-daemon configuration option for selecting audit log backend.
    Linux Audit support via new LinuxAudit backend.
    Added missing RuleCondition.hpp header file to the public API headers.
  - Changed
    Qt Applet: disabled session management
    usbguard-daemon console logging output is enabled by default now.  Previously, the -k option had to be passed to enable the output.
    Replaced --enable-maintainer-mode configure option with --enable-full-test-suite option. When the new option is not used during the configure phase, only a basic set of test is run during the make check phase.
    usbguard-daemon now opens configuration in read-only mode
    Fixed UEventDeviceManager to work with Linux Kernel >= 4.13
    Refactored audit logging to support different audit log backends
    Made the configuration parser strict. Unknown directives and wrong syntax will cause an error.
- Added usbguard-applet-qt package to allow easier user interaction
- Added usbguard-applet-qt_desktop_menu_categories.patch to fix category
- Updated usbguard-daemon.conf to upstream version
- Removed obsolte patch usbguard-fixes.patch
- Added rules.conf, fixing bsc#1071076
* Wed Sep  6 2017 meissner@suse.com
- updated to 0.7.0
  - Added
    Added InsertedDevicePolicy configuration option to control the policy method for inserted devices.
    Added RestoreControllerDeviceState configuration option.
    Added DeviceManagerBackend configuration option. This option can be used to select from several device manager backend implementations.
    Implemented an uevent based device manager backend.
    Added setParameter, getParameter IPC (incl. D-Bus) methods.
    Added set-parameter, get-parameter CLI subcommands.
    Qt Applet: Added Spanish (es_AR) translation.
    Create empty rules.conf file at install time (make install).
    Support for numeric UID/GID values in IPCAllowedUsers and IPCAllowedGroups settings.
    If bash completion support is detected at configure time, install the bash completion script during make install.
    Added new configuration setting: IPCAccessControlFiles.
    IPC access is now configurable down to a section and privilege level per user and/or group.
    Added add-user, remove-user usbuard CLI subcommands for creating, removing IPC access control files.
    Added AuditFilePath configuration option for setting the location of the USBGuard audit events log file path. If set, the usbguard-daemon will log policy and device related actions and whether they succeeded or not.
  - Removed
    Removed UDev based device manager backend and UDev related dependencies.
    Removed UDev development files/API dependecy
  - Changed
    Reset Linux root hub bcdDevice value before updating device hash. This is a backwards incompatible change because it changes how the device hash is computed for Linux root hub devices.
    Refactored low-level USB device handling into SysFSDevice class which represents a device in the /sys filesystem (sysfs).
    Removed usage of readdir_r because it's obsolete. Replaced with readdir with the assumption that its usage is thread-safe if the directory handle passed to it is not shared between threads.
    Extended test suite with use case tests.
    Install the usbguard-daemon configuration and policy file with strict file permissions to prevent policy leaks.
    Fixed several memory leaks.
    Don't pre-resolve user and group names in IPCAllowedUsers and IPCAllowedGroups settings. Instead, resolve the name during the IPC authentication phase.
- Updated to 0.6.2
    Wait for disconnect in IPCClient dtor if needed
    Qt Applet: Fixed loading of decision method and default decision settings
- Updated to 0.6.1
  - Changed
    Refactored logging subsystem
    Fixed handling of IPC disconnect in the IPCClient class
    Qt Applet: Fixed handling of main window minimization and maximization
    Fixed building on architectures that don't provide required atomic operations.
    The libatomic emulation library will be used in such cases.
    Fixed several typos in the documentation
  - Added
    Implemented a simple internal logger
    Access to the logger via public API
    Improved logging coverage. Logging output can be enabled either via
    CLI options or by setting the USBGUARD_DEBUG environment variable to 1.
    Qt Applet: UI translation support.
    Qt Applet: Czech (cs_CZ) translation
  - Removed
    Removed spdlog dependency
- ....  ommitted changes from 0.5* series ..
* Tue Mar  1 2016 meissner@suse.com
- split off a library package libusbguard0
* Sun Jan 31 2016 meissner@suse.com
- a daemon and framework and tools to guard against bad usb
  devices.
